#!/bin/bash -l

##############################
# SLURM
# NOTE: used for this script only, NOT for the snakemake call below

#SBATCH -J ONT_SMK
#SBATCH -N 1
#SBATCH -n 1
#SBATCH -c 1
#SBATCH --time=2-00:00:00
#SBATCH -p batch
#SBATCH --qos=qos-batch
#SBATCH --mail-type=end,fail
#SBATCH --mail-user=valentina.galata@uni.lu

##############################
# SNAKEMAKE

# conda env name
ONTP_ENV="ONT_pilot"
# number of cores for snakemake
ONTP_CORES=20
# snakemake file
ONTP_SMK="workflow_fast5/Snakefile"
# config file
ONTP_CONFIG="config/Zymo-GridION-EVEN-BB-SN/config.fast5.yaml"
# slurm config file
ONTP_SLURM="config/Zymo-GridION-EVEN-BB-SN/slurm.fast5.yaml"
# slurm cluster call
ONTP_CLUSTER="-p {cluster.partition} -q {cluster.qos} {cluster.explicit} -N {cluster.nodes} -n {cluster.n} -c {threads} -t {cluster.time} --job-name={cluster.job-name}"

##############################
# Snakemake

# activate the env
conda activate ${ONTP_ENV}

# run the pipeline
snakemake -s ${ONTP_SMK} -rp --cores ${ONTP_CORES} --configfile ${ONTP_CONFIG} \
--use-conda --conda-prefix ${CONDA_PREFIX}/pipeline \
--cluster-config ${ONTP_SLURM} --cluster "sbatch ${ONTP_CLUSTER}"
