# Align proteins from one assembly to the proteins of another assembly

# diamond CMD: http://www.diamondsearch.org/index.php?pages/command_line_options/

# conda
conda activate /home/users/vgalata/miniconda3/envs/ONT_pilot/pipeline/857cb426

# data
prot1="/scratch/users/vgalata/GDB/results/annotation/prodigal/lr/flye/proteins.faa"
prot2="/scratch/users/vgalata/GDB/results/annotation/prodigal/lr/canu/proteins.faa"
db1="./lr_flye_proteins"
db2="./lr_canu_proteins"
daa1="./lr_flye__lr_canu.daa"
daa2="./lr_canu__lr_flye.daa"
tsv1="./lr_flye__lr_canu.tsv"
tsv2="./lr_canu__lr_flye.tsv"
outfmt="6 qseqid sseqid pident length mismatch gapopen qstart qend sstart send evalue bitscore qlen slen"

# DBs (very fast - seconds, will add "*.dmnd" as extension)
diamond makedb --in ${prot1} --db ${db1} --threads 5
diamond makedb --in ${prot2} --db ${db2} --threads 5

# alignment (fast - minutes)
diamond blastp -q ${prot2} --db ${db1} --out ${daa1} --threads 5 --outfmt 100 --id 90 --query-cover 90 --subject-cover 90 --more-sensitive
diamond blastp -q ${prot1} --db ${db2} --out ${daa2} --threads 5 --outfmt 100 --id 90 --query-cover 90 --subject-cover 90 --more-sensitive

# tsv
diamond view --daa ${daa1%.*} --max-target-seqs 1 --threads 5 --outfmt ${outfmt} --out ${tsv1}
diamond view --daa ${daa2%.*} --max-target-seqs 1 --threads 5 --outfmt ${outfmt} --out ${tsv2}

# qcov, scov, query/subject length ratio
awk -F"\t" '{qcov=100*sqrt(($8-$7+1)^2)/$13; scov=100*sqrt(($10-$9+1)^2)/$14; qslr=$13/$14; print $0"\t"qcov"\t"scov"\t"qslr}' ${tsv1} > ${tsv1}.more
awk -F"\t" '{qcov=100*sqrt(($8-$7+1)^2)/$13; scov=100*sqrt(($10-$9+1)^2)/$14; qslr=$13/$14; print $0"\t"qcov"\t"scov"\t"qslr}' ${tsv2} > ${tsv2}.more

# stats
echo -e "
flye: $(grep '^>' ${prot1} | wc -l) proteins
canu: $(grep '^>' ${prot2} | wc -l) proteins
unique matches in flye: $(cut -f1,3,15,16,17 ${tsv1}.more | awk -F'\t' '$2>=90.0 && $3>=90.0 && $4>=90 {print $1}' | sort | uniq | wc -l)
unique matches in canu: $(cut -f1,3,15,16,17 ${tsv2}.more | awk -F'\t' '$2>=90.0 && $3>=90.0 && $4>=90 {print $1}' | sort | uniq | wc -l)
"