# https://github.com/soedinglab/MMseqs2/wiki#batch-sequence-searching-using-mmseqs-search
# https://github.com/soedinglab/MMseqs2/wiki#set-sensitivity--s-parameter
# https://github.com/soedinglab/MMseqs2/wiki#how-to-find-the-best-hit-the-fastest-way

conda activate /home/users/vgalata/miniconda3/envs/ONT_pilot/pipeline/c363035f

# data
asm1="/mnt/lscratch/users/vgalata/ont_pilot/results/annotation/prodigal/lr/flye/proteins.faa"
asm2="/mnt/lscratch/users/vgalata/ont_pilot/results/annotation/prodigal/sr/metaspades/proteins.faa"
db1="lr_flye"
db2="sr_metaspades"
out12="${db1}__${db2}"
out21="${db2}__${db1}"

# db
mmseqs createdb ${asm1} ${db1}
mmseqs createdb ${asm2} ${db2}

# index
mmseqs createindex ${db1} tmp
mmseqs createindex ${db2} tmp

# search: query target
mmseqs search ${db1} ${db2} ${out12} tmp --start-sens 1 --sens-steps 3 -s 7 --threads 5 -v 3
mmseqs search ${db2} ${db1} ${out21} tmp --start-sens 1 --sens-steps 3 -s 7 --threads 5 -v 3

# tables
mmseqs convertalis ${db1} ${db2} ${out12} ${out12}.tsv --format-output "query,target,qcov,tcov,evalue,pident,nident,gapopen,mismatch,alnlen,qstart,qend,qlen,tstart,tend,tlen"
mmseqs convertalis ${db2} ${db1} ${out21} ${out21}.tsv --format-output "query,target,qcov,tcov,evalue,pident,nident,gapopen,mismatch,alnlen,qstart,qend,qlen,tstart,tend,tlen"

# stats
awk -F'\t' '$3 >= 0.9 && $4 >= 0.9 && $6 >= 0.9 {print $0}' ${out12}.tsv | cut -f1 | sort | uniq | wc -l
awk -F'\t' '{printf "%.1f\n", $4}' ${out21}.tsv | sort | uniq -c | sed 's/^\s\+//' | sort -k2,2 -n